==> mishkal_hebrew-0.3.2.tar.gz: mishkal_hebrew-0.3.2/mishkal/expander/number_names.py <==
"""
See https://github.com/savoirfairelinux/num2words/blob/master/num2words/lang_HE.py
"""

ZERO = {"אפס": "אֶפֶס"}


ONES = {
    "אחת": "אַחַת",
    "אחד": "אֶחָד",
    "ראשונה": "רִאשׁוֹנָה",
    "ראשון": "רִאשׁוֹן",
    "ראשונות": "רִאשׁוֹנוֹת",
    "ראשונים": "רִאשׁוֹנִים",
    "שתיים": "שְׁתַּיִם",
    "שניים": "שְׁנַיִם",
    "שתי": "שְׁתֵּי",
    "שני": "שְׁנֵי",
    "שנייה": "שְׁנִיָּה",
    "שניות": "שְׁנִיּוֹת",
    "שלוש": "שָׁלוֹשׁ",
    "שלושה": "שְׁלוֹשָׁה",
    "שלושת": "שְׁלוֹשֶׁת",
    "שלישית": "שְׁלִישִׁית",
    "שלישי": "שְׁלִישִׁי",
    "שלישיות": "שְׁלִישִׁיּוֹת",
    "שלישיים": "שְׁלִישִׁיִּים",
    "ארבע": "אַרְבַּע",
    "ארבעה": "אַרְבַּעָה",
    "ארבעת": "אַרְבַּעַת",
    "רביעית": "רֵבִיעִית",
    "רביעי": "רֵבִיעִי",
    "רביעיות": "רֵבִיעִיוֹת",
    "רביעיים": "רֵבִיעִיִּים",
    "חמש": "חָמֵשׁ",
    "חמישה": "חֲמִשָּׁה",
    "חמשת": "חֲמֵשֶׁת",
    "חמישית": "חֲמִישִּׁית",
    "חמישי": "חֲמִישִּׁי",
    "חמישיות": "חֲמִישִּׁיוֹת",
    "חמישיים": "חֲמִישִּׁיִּים",
    "שש": "שֵׁשׁ",
    "שישה": "שִׁשָּׁה",
    "ששת": "שֵׁשֶׁת",
    "שישית": "שִׁשִּׁית",
    "שישי": "שִׁשִּׁי",
    "שישיות": "שִׁשִּׁיוֹת",
    "שישיים": "שִׁשִּׁיִּים",
    "שבע": "שֶׁבַע",
    "שבעה": "שִׁבְעָה",
    "שבעת": "שִׁבְעַת",
    "שביעית": "שְׁבִיעִית",
    "שביעי": "שְׁבִיעִי",
    "שביעיות": "שְׁבִיעִיוֹת",
    "שביעיים": "שְׁבִיעִיִּים",
    "שמונה": "שְׁמוֹנֶה",
    "שמונת": "שְׁמוֹנַת",
    "שמינית": "שְׁמִינִית",
    "שמיני": "שְׁמִינִי",
    "שמיניות": "שְׁמִינִיוֹת",
    "שמיניים": "שְׁמִינִיִּים",
    "תשע": "תֵּשַׁע",
    "תשעה": "תִּשְׁעָה",
    "תשעת": "תִּשְׁעַת",
    "תשיעית": "תְּשִׁיעִית",
    "תשיעי": "תְּשִׁיעִי",
    "תשיעיות": "תְּשִׁיעִיּוֹת",
    "תשיעיים": "תְּשִׁיעִיִּים",
}


TENS = {
    "עשר": "עֶשֶׂר",
    "עשרה": "עֲשָׁרָה",
    "עשרת": "עֲשֶׁרֶת",
    "עשירית": "עֲשִׁירִית",
    "עשירי": "עֲשִׁירִי",
    "עשיריות": "עֲשִׁירִיוֹת",
    "עשיריים": "עֲשִׁירִיִּים",
    "שתים עשרה": "שְׁתֵּים עֶשְׂרֵה",
    "שנים עשר": "שְׁנֵים עָשָׂר",
}


TWENTIES = {
    "עשרים": "עֶשְׂרִים",
    "שלושים": "שְׁלוֹשִׁים",
    "ארבעים": "אַרְבָּעִים",
    "חמישים": "חֲמִשִּׁים",
    "שישים": "שִׁשִּׁים",
    "שבעים": "שִׁבְעִים",
    "שמונים": "שְׁמוֹנִים",
    "תשעים": "תִּשְׁעִים",
}


HUNDREDS = {
    "מאה": "מֵאָה",
    "מאת": "מֵאַת",
    "מאתיים": "מָאתַיִם",
    "מאות": "מֵאוֹת",
}

THOUSANDS = {
    "אלף": "אֶלֶף",
    "אלפיים": "אַלְפַּיִם",
    "אלפים": "אֲלָפִים",
    "אלפי": "אַלְפִּי",
}


LARGE = {
    "מיליון": "מִילְיוֹן",
    "מיליוני": "מִילְיוֹנִי",
    "מיליארד": "מִילְיַארְד",
    "מיליארדי": "מִילְיַארְדִּי",
    "טריליון": "טְרִילְיוֹן",
    "טריליוני": "טְרִילְיוֹנִי",
    "קוודריליון": "קוֹוַדְרִילְיוֹן",
    "קוודריליוני": "קוֹוַדְרִילְיוֹנִי",
    "קווינטיליון": "קוִוִּנְטִילְיוֹן",
    "קווינטיליוני": "קוִוִּנְטִילְיוֹנִי",
    "סקסטיליון": "סְקֶסְטִילְיוֹן",
    "סקסטיליוני": "סְקֶסְטִילְיוֹנִי",
    "ספטיליון": "סְפֶּטִילְיוֹן",
    "ספטיליוני": "סְפֶּטִילְיוֹנִי",
    "אוקטיליון": "אוֹקְטִילְיוֹן",
    "אוקטיליוני": "אוֹקְטִילְיוֹנִי",
    "נוניליון": "נוּנִילְיוֹן",
    "נוניליוני": "נוּנִילְיוֹנִי",
    "דסיליון": "דֶּסִילְיוֹן",
    "דסיליוני": "דֶּסִילְיוֹנִי",
    "אונדסיליון": "אוּנְדְסִילְיוֹן",
    "אונדסיליוני": "אוּנְדְסִילְיוֹנִי",
    "דואודסיליון": "דוּאודְסִילְיוֹן",
    "דואודסיליוני": "דוּאודְסִילְיוֹנִי",
    "טרדסיליון": "טֶרְדְסִילְיוֹן",
    "טרדסיליוני": "טֶרְדְסִילְיוֹנִי",
    "קווטואורדסיליון": "קוּוטְוָאורְדְסִילְיוֹן",
    "קווטואורדסיליוני": "קוּוטְוָאורְדְסִילְיוֹנִי",
    "קווינדסיליון": "קוִוִּנְדְסִילְיוֹן",
    "קווינדסיליוני": "קוִוִּנְדְסִילְיוֹנִי",
    "סקסדסיליון": "סֶקְסְדְסִילְיוֹן",
    "סקסדסיליוני": "סֶקְסְדְסִילְיוֹנִי",
    "ספטנדסיליון": "סְפֶּטַנְדְסִילְיוֹן",
    "ספטנדסיליוני": "סְפֶּטַנְדְסִילְיוֹנִי",
    "אוקטודסיליון": "אוֹקְטוֹדְסִילְיוֹן",
    "אוקטודסיליוני": "אוֹקְטוֹדְסִילְיוֹנִי",
    "נובמדסיליון": "נוֹבְמַדְסִילְיוֹן",
    "נובמדסיליוני": "נוֹבְמַדְסִילְיוֹנִי",
    "ויגינטיליון": "וִיגִּינְטִילְיוֹן",
    "ויגינטיליוני": "וִיגִּינְטִילְיוֹנִי",
}


LETTERS = {
    "ו": "וֵ",
    "ה": "הַ",
}


CURRENCY = {
    "שקל": "שֵׁקֶל",
    "שקלים": "שְׁקָלִים",
    "אגורה": "אֲגוֹרָה",
    "אגורות": "אֲגוֹרוֹת",
    "אירו": "אֵירוֹ",
    "סנט": "סֵנְט",
    "סנטים": "סֵנְטִים",
    "דולר": "דוֹלָר",
    "דולרים": "דוֹלָרִים",
}


POINTS = {
    "מינוס": "מִינּוּס",
    "נקודה": "נְקֻדָּה",
}

NUMBER_NAMES = {
    **CURRENCY,
    **HUNDREDS,
    **LARGE,
    **LETTERS,
    **ONES,
    **POINTS,
    **TENS,
    **THOUSANDS,
    **TWENTIES,
    **ZERO,
}

==> mishkal_hebrew-0.3.4.tar.gz: mishkal_hebrew-0.3.4/mishkal/expander/number_names.py <==
"""
See https://github.com/savoirfairelinux/num2words/blob/master/num2words/lang_HE.py
"""

# TODO: add niqqud hints

ZERO = {"אפס": "אֶפֶס"}


ONES = {
    "אחת": "אַחַת",
    "אחד": "אֶחָד",
    "ראשונה": "רִאשׁוֹנָה",
    "ראשון": "רִאשׁוֹן",
    "ראשונות": "רִאשׁוֹנוֹת",
    "ראשונים": "רִאשׁוֹנִים",
    "שתיים": "שְׁתַּיִם",
    "שניים": "שְׁנַיִם",
    "שתי": "שְׁתֵּי",
    "שני": "שְׁנֵי",
    "שנייה": "שְׁנִיָּה",
    "שניות": "שְׁנִיּוֹת",
    "שלוש": "שָׁלוֹשׁ",
    "שלושה": "שְׁלוֹשָׁה",
    "שלושת": "שְׁלוֹשֶׁת",
    "שלישית": "שְׁלִישִׁית",
    "שלישי": "שְׁלִישִׁי",
    "שלישיות": "שְׁלִישִׁיּוֹת",
    "שלישיים": "שְׁלִישִׁיִּים",
    "ארבע": "אַרְבַּע",
    "ארבעה": "אַרְבַּעָה",
    "ארבעת": "אַרְבַּעַת",
    "רביעית": "רֵבִיעִית",
    "רביעי": "רֵבִיעִי",
    "רביעיות": "רֵבִיעִיוֹת",
    "רביעיים": "רֵבִיעִיִּים",
    "חמש": "חָמֵשׁ",
    "חמישה": "חֲמִשָּׁה",
    "חמשת": "חֲמֵשֶׁת",
    "חמישית": "חֲמִישִּׁית",
    "חמישי": "חֲמִישִּׁי",
    "חמישיות": "חֲמִישִּׁיוֹת",
    "חמישיים": "חֲמִישִּׁיִּים",
    "שש": "שֵׁשׁ",
    "שישה": "שִׁשָּׁה",
    "ששת": "שֵׁשֶׁת",
    "שישית": "שִׁשִּׁית",
    "שישי": "שִׁשִּׁי",
    "שישיות": "שִׁשִּׁיוֹת",
    "שישיים": "שִׁשִּׁיִּים",
    "שבע": "שֶׁבַע",
    "שבעה": "שִׁבְעָה",
    "שבעת": "שִׁבְעַת",
    "שביעית": "שְׁבִיעִית",
    "שביעי": "שְׁבִיעִי",
    "שביעיות": "שְׁבִיעִיוֹת",
    "שביעיים": "שְׁבִיעִיִּים",
    "שמונה": "שְׁמוֹנֶה",
    "שמונת": "שְׁמוֹנַת",
    "שמינית": "שְׁמִינִית",
    "שמיני": "שְׁמִינִי",
    "שמיניות": "שְׁמִינִיוֹת",
    "שמיניים": "שְׁמִינִיִּים",
    "תשע": "תֵּשַׁע",
    "תשעה": "תִּשְׁעָה",
    "תשעת": "תִּשְׁעַת",
    "תשיעית": "תְּשִׁיעִית",
    "תשיעי": "תְּשִׁיעִי",
    "תשיעיות": "תְּשִׁיעִיּוֹת",
    "תשיעיים": "תְּשִׁיעִיִּים",
}


TENS = {
    "עשר": "עֶשֶׂר",
    "עשרה": "עֲשָׁרָה",
    "עשרת": "עֲשֶׁרֶת",
    "עשירית": "עֲשִׁירִית",
    "עשירי": "עֲשִׁירִי",
    "עשיריות": "עֲשִׁירִיוֹת",
    "עשיריים": "עֲשִׁירִיִּים",
    "שתים עשרה": "שְׁתֵּים עֶשְׂרֵה",
    "שנים עשר": "שְׁנֵים עָשָׂר",
}


TWENTIES = {
    "עשרים": "עֶשְׂרִ֫ים",
    "שלושים": "שְׁלוֹשִׁים",
    "ארבעים": "אַרְבָּעִים",
    "חמישים": "חֲמִשִּׁים",
    "שישים": "שִׁשִּׁים",
    "שבעים": "שִׁבְעִים",
    "שמונים": "שְׁמוֹנִים",
    "תשעים": "תִּשְׁעִים",
}


HUNDREDS = {
    "מאה": "מֵאָה",
    "מאת": "מֵאַת",
    "מאתיים": "מָאתַיִם",
    "מאות": "מֵאוֹת",
}

THOUSANDS = {
    "אלף": "אֶלֶף",
    "אלפיים": "אַלְפַּיִם",
    "אלפים": "אֲלָפִים",
    "אלפי": "אַלְפִּי",
}


LARGE = {
    "מיליון": "מִילְיוֹן",
    "מיליוני": "מִילְיוֹנִי",
    "מיליארד": "מִילְיַארְד",
    "מיליארדי": "מִילְיַארְדִּי",
    "טריליון": "טְרִילְיוֹן",
    "טריליוני": "טְרִילְיוֹנִי",
    "קוודריליון": "קוֹוַדְרִילְיוֹן",
    "קוודריליוני": "קוֹוַדְרִילְיוֹנִי",
    "קווינטיליון": "קוִוִּנְטִילְיוֹן",
    "קווינטיליוני": "קוִוִּנְטִילְיוֹנִי",
    "סקסטיליון": "סְקֶסְטִילְיוֹן",
    "סקסטיליוני": "סְקֶסְטִילְיוֹנִי",
    "ספטיליון": "סְפֶּטִילְיוֹן",
    "ספטיליוני": "סְפֶּטִילְיוֹנִי",
    "אוקטיליון": "אוֹקְטִילְיוֹן",
    "אוקטיליוני": "אוֹקְטִילְיוֹנִי",
    "נוניליון": "נוּנִילְיוֹן",
    "נוניליוני": "נוּנִילְיוֹנִי",
    "דסיליון": "דֶּסִילְיוֹן",
    "דסיליוני": "דֶּסִילְיוֹנִי",
    "אונדסיליון": "אוּנְדְסִילְיוֹן",
    "אונדסיליוני": "אוּנְדְסִילְיוֹנִי",
    "דואודסיליון": "דוּאודְסִילְיוֹן",
    "דואודסיליוני": "דוּאודְסִילְיוֹנִי",
    "טרדסיליון": "טֶרְדְסִילְיוֹן",
    "טרדסיליוני": "טֶרְדְסִילְיוֹנִי",
    "קווטואורדסיליון": "קוּוטְוָאורְדְסִילְיוֹן",
    "קווטואורדסיליוני": "קוּוטְוָאורְדְסִילְיוֹנִי",
    "קווינדסיליון": "קוִוִּנְדְסִילְיוֹן",
    "קווינדסיליוני": "קוִוִּנְדְסִילְיוֹנִי",
    "סקסדסיליון": "סֶקְסְדְסִילְיוֹן",
    "סקסדסיליוני": "סֶקְסְדְסִילְיוֹנִי",
    "ספטנדסיליון": "סְפֶּטַנְדְסִילְיוֹן",
    "ספטנדסיליוני": "סְפֶּטַנְדְסִילְיוֹנִי",
    "אוקטודסיליון": "אוֹקְטוֹדְסִילְיוֹן",
    "אוקטודסיליוני": "אוֹקְטוֹדְסִילְיוֹנִי",
    "נובמדסיליון": "נוֹבְמַדְסִילְיוֹן",
    "נובמדסיליוני": "נוֹבְמַדְסִילְיוֹנִי",
    "ויגינטיליון": "וִיגִּינְטִילְיוֹן",
    "ויגינטיליוני": "וִיגִּינְטִילְיוֹנִי",
}


LETTERS = {
    "ו": "וֵ",
    "ה": "הַ",
}


CURRENCY = {
    "שקל": "שֵׁקֶל",
    "שקלים": "שְׁקָלִים",
    "אגורה": "אֲגוֹרָה",
    "אגורות": "אֲגוֹרוֹת",
    "אירו": "אֵירוֹ",
    "סנט": "סֵנְט",
    "סנטים": "סֵנְטִים",
    "דולר": "דוֹלָר",
    "דולרים": "דוֹלָרִים",
}


POINTS = {
    "מינוס": "מִינּוּס",
    "נקודה": "נְקֻדָּה",
}

NUMBER_NAMES = {
    **CURRENCY,
    **HUNDREDS,
    **LARGE,
    **LETTERS,
    **ONES,
    **POINTS,
    **TENS,
    **THOUSANDS,
    **TWENTIES,
    **ZERO,
}
